<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Inertia\Inertia;

class NotificationController extends Controller
{
    public function compose(Request $request)
    {
        $this->notify(
            to: $request->to,
            title: $request->title,
            body: $request->body,
            action: $request->action,
            imageUrl: $request->imageUrl);
        return back();
    }

    public static function notify($to, $title, $body, $action = null, $imageUrl = null)
    {

        $user = null;
        $customer = null;
        $topic = null;
        $device_token = null;

        if (preg_match('/^(user:|topic:)(.+)$/', $to, $matches)) {
            $prefix = $matches[1];
            $to = $matches[2];

            switch ($prefix) {
                case 'user:':
                    $user = User::where('email', trim($to))->orWhere('id', $to)->first();
                    if (!$user) {
                        return;
                    }
                    $device_token = $user->device_token;

                    break;
                case 'topic:':
                    $topic = $to;
                    break;
                    // Handle other prefixes or cases here if needed
            }
        } else {
            return; // Invalid format, do nothing
        }
        if ($user and !$user->notify) {
            return;
        }

        $serverKey = env('FCM_SERVER_KEY'); // Replace with your FCM server key
        // Set the FCM endpoint URL
        $url = 'https://fcm.googleapis.com/fcm/send';
        // Create the FCM notification payload
        $notificationArr = [
            'to' => ($topic ? '/topics/' . $topic : $device_token),
            'notification' => [
                'title' => $title,
                'body' => $body,
                'image' => $imageUrl,
                'click_action' => $action,
                'icon' => url('/favicon.ico'),
            ],
            'data' => [
                'image' => $imageUrl,
            ],
        ];
        // Convert the payload to JSON
        $jsonNotification = json_encode($notificationArr);

        // Set the HTTP headers for the request
        $headers = [
            'Authorization: key=' . $serverKey,
            'Content-Type: application/json',
        ];

        // Initialize cURL session
        $ch = curl_init();

        // Set cURL options
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonNotification);

        // Execute the cURL request
        $response = curl_exec($ch);
        // dd(1);

        // Check for cURL errors
        if (curl_errno($ch)) {

            return;
        } else {
            // Close cURL session
            curl_close($ch);

        }
    }

    public function index(Request $request)
    {
        return Inertia::render('Notifications')->title('Notifications');
    }

    public function create()
    {
        return Inertia::render('Admin/SendNotifications')->title('Send Notification');
    }
}
