<?php

namespace App\Http\Controllers;

use App\Models\Project;
use Illuminate\Http\Request;
use Inertia\Inertia;

class ProjectController extends Controller
{

    public function index()
    {
        return Inertia::render('Admin/Projects')
            ->title('Projects');
    }

    public function create()
    {
        return Inertia::render('Admin/SaveProject')
            ->title('Create project');
    }

    public function update(Request $request)
    {
        $project = Project::find($request->id);

        if (!$project) {
            abort(404);
        }

        return Inertia::render('Admin/SaveProject', [
            'project' => $project,
        ])
            ->title('Update project');
    }

    public function save(Request $request)
    {
        $project = new Project();
        if ($request->project_id) {
            $project = Project::find($request->project_id);
        }
        $request->validate([
            'title' => 'required|max:80|unique:projects,title,' . $request->project_id,
            'description' => 'nullable|max:255',
            'link' => 'nullable',
        ]);
        $project->title = $request->title;
        $project->description = $request->description;
        $project->link = $request->link;
        if ($project?->save()) {
            return back()->with('success', 'Saved');
        }
    }

    public function delete(Request $request)
    {
        if ($request->user()->role == 1) {
            $project = Project::find($request->project_id);
            if ($project?->delete()) {
                return back()->with('success', 'Deleted');
            }
        }

    }
    public function get(Request $request)
    {
        $data = Project::query();

        if ($request->project_id) {
            $data = Project::find($request->project_id);
        } else {
            if ($request->key) {
                // Perform a search on the 'project' model using the search method
                $data = $data->search($request->key);
            }
            $data = $data->paginate($request->perpage);
        }

        return response()->json($data);
    }

}
