<?php

namespace App\Notifications;

use App\Http\Controllers\NotificationController;
use App\Notifications\FcmChannel;
use Illuminate\Bus\Queueable;
use Illuminate\Notifications\Notification;

class CustomNotification extends Notification
{
    use Queueable;

    protected $title;
    protected $body;
    protected $action;
    protected $image;

    /**
     * Create a new notification instance.
     */
    public function __construct($title = null, $body = null, $action = null, $image = null)
    {
        $this->title = $title;
        $this->body = $body;
        $this->action = $action;
        $this->image = $image;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return [FcmChannel::class, 'database'];
    }

    /**
     * Get the FCM representation of the notification.
     */
    public function toFcm(object $notifiable): array
    {
        NotificationController::notify(
            to: $notifiable->device_token,
            title: $this->title,
            body: $this->body,
            action: $this->action,
            imageUrl: $this->image);
        return [
            'title' => $this->title,
            'body' => $this->body,
            'action' => $this->action,
            'image' => $this->image,
        ];
    }

    /**
     * Get the array representation of the notification.
     *
     * @return array<string, mixed>
     */
    public function toArray(object $notifiable): array
    {
        return [
            'title' => $this->title,
            'body' => $this->body,
            'action' => $this->action,
            'image' => $this->image,
        ];
    }
}
