import { useState } from "react";

export function Alert({ icon, type, title, message }) {
    document.dispatchEvent(
        new CustomEvent("alert", {
            detail: { icon, type, title, message },
        })
    );
}

export function AlertBox({}) {
    const [state, setState] = useState({
        icon: null,
        type: null,
        title: null,
        message: null,
        show: false,
    });

    document.addEventListener("alert", function (e) {
        setState((preState) => ({ ...preState, ...e.detail, show: true }));
        setTimeout(() => {
            setState((preState) => ({ ...preState, show: false }));
        }, 3000);
    });

    if (!state.show) return "";
    return (
        <div
            className={
                "border p-3  rounded-md bg-white shadow-md fixed bottom-5 right-5 flex gap-5 transition-all duration-500 ease-in-out" +
                " " +
                " " +
                (state.type == "success"
                    ? "text-emerald-600"
                    : state.type == "warning"
                    ? "text-yellow-500 "
                    : state.type == "error"
                    ? "text-red-500 "
                    : "text-black dark:text-white") +
                " " +
                (state.type == "success"
                    ? "border-emerald-600"
                    : state.type == "warning"
                    ? "border-yellow-500 "
                    : state.type == "error"
                    ? "border-red-500 "
                    : "border-black dark:border-white")
            }
        >
            <div>
                <b>{state.title}</b>
                <p>{state.message}</p>
            </div>
            <div className="ml-auto flex justify-center items-center">
                <button
                    type="button"
                    onClick={() =>
                        setState((preState) => ({ ...preState, show: false }))
                    }
                >
                    <svg
                        xmlns="http://www.w3.org/2000/svg"
                        fill="none"
                        viewBox="0 0 24 24"
                        strokeWidth={1.5}
                        stroke="currentColor"
                        className="w-6 h-6"
                    >
                        <path
                            strokeLinecap="round"
                            strokeLinejoin="round"
                            d="M6 18L18 6M6 6l12 12"
                        />
                    </svg>
                </button>
            </div>
        </div>
    );
}
