import { useRemember } from "@inertiajs/react";
import { Postcard, PostcardSkeleton } from "@/Components/Postcard";
import axios from "axios";
import { useState } from "react";

export default function LoadMorePosts({ auth, initialposts, params }) {
    const [state, setState] = useRemember(
        {
            page: initialposts ? (initialposts.next_page_url ? 2 : false) : 1,
            posts: initialposts ? initialposts.data : [],
        },
        "fetch_posts" + window.location.href
    );
    const [loading, setLoading] = useState(false);

    function loadmore() {
        if (!state.page || loading) return;

        setLoading(true);

        axios
            .post(route("posts"), { page: state.page, perpage: 1, ...params })
            .then((res) => {
                const updatedPosts = [...state.posts, ...res.data.data];

                setState((prev) => ({
                    ...prev,
                    posts: updatedPosts,
                    page: res.data.next_page_url ? state.page + 1 : false,
                }));
            })
            .catch((error) => {
                // Handle error
                console.error("Error loading more posts:", error);
            })
            .finally(() => {
                setLoading(false);
            });
    }

    return (
        <>
            <div className="md:columns-2 mt-10 space-y-10">
                {state.posts.map((post) => (
                    <Postcard post={post} auth={auth} key={post.id} />
                ))}
                {loading
                    ? [...Array(5)].map((_, index) => (
                          <PostcardSkeleton key={index} />
                      ))
                    : ""}
            </div>
            <div className="text-center mt-4 uplink">
                {loading ? (
                    ""
                ) : state.page ? (
                    <button onClick={loadmore} className="uplink">
                        Load more
                    </button>
                ) : (
                    ""
                )}
            </div>
        </>
    );
}
