import { Link } from "@inertiajs/react";
import {
    calculateReadingTime,
    countComments,
    stripTags,
    dateFormat,
} from "@/Libs/Common";
import { marked } from "marked";

import { router } from "@inertiajs/react";

export function Postcard({ post, auth, actions = false }) {
    const { title, content, topic, slug, created_at, likes, comments } = post;
    const Liked = likes.filter((r) => r.user_id == auth.user?.id).length;
    const commentCount = comments.length ? countComments(comments) : null;
    return (
        <div className="break-inside-avoid-column flex flex-col gap-4 ">
            {post.cover_image && (
                <img
                    src={"/storage/cover/" + post.cover_image}
                    alt=""
                    className="rounded-xl"
                />
            )}

            <div className="flex ">
                {topic && (
                    <div>
                        <Link href={"/?topic=" + topic.name} className="uplink">
                            {topic.name}
                        </Link>
                    </div>
                )}
                <div className="flex gap-1 items-center text-slate-600 uppercase ml-auto text-xs px-3">
                    <svg
                        xmlns="http://www.w3.org/2000/svg"
                        fill="none"
                        viewBox="0 0 24 24"
                        strokeWidth={1.5}
                        stroke="currentColor"
                        className="w-4 h-4"
                    >
                        <path
                            strokeLinecap="round"
                            strokeLinejoin="round"
                            d="M12 6v6h4.5m4.5 0a9 9 0 11-18 0 9 9 0 0118 0z"
                        />
                    </svg>
                    {calculateReadingTime(content)} min
                    <div className="ml-3 ">{dateFormat(created_at)}</div>
                </div>
            </div>

            <Link href={"/posts/" + slug} className="hover:underline">
                <h3 className="font-semibold">{title}</h3>
            </Link>

            <article
                dangerouslySetInnerHTML={{
                    __html: stripTags(marked.parse(content)).substring(0, 150),
                }}
            />
            {actions ? (
                <div className="flex gap-1 items-center justify-center">
                    <div className="flex-grow flex items-center justify-center gap-1">
                        <button
                            type="button"
                            onClick={(e) => {
                                if (auth.user) {
                                    return router.post(
                                        route("like"),
                                        {
                                            post_id: post.id,
                                        },
                                        {
                                            preserveState: false,
                                            preserveScroll: true,
                                        }
                                    );
                                }
                                router.visit("login");
                            }}
                            className={"uplink " + (Liked ? " font-bold" : "")}
                        >
                            {likes.length
                                ? likes.length +
                                  (likes.length > 1 ? " likes " : " like ")
                                : "Like"}
                        </button>
                    </div>
                    {/* <div className="flex-grow">&bull;</div> */}
                    <div className="flex-grow flex items-center justify-center gap-1">
                        <Link
                            href={"/posts/" + slug + "/#comments"}
                            className="uplink "
                        >
                            {comments.length
                                ? commentCount +
                                  (commentCount > 1 ? " comments" : " comment")
                                : " Comment"}
                        </Link>
                    </div>
                    {/* <div className="flex-grow">&bull;</div> */}
                    <div className="flex-grow flex items-center justify-center gap-1">
                        <button
                            type="button"
                            className="uplink "
                            onClick={() => {
                                if (navigator.share) {
                                    navigator
                                        .share({
                                            title: document.title,
                                            // text: "Hello World",
                                            url: window.location.href,
                                        })
                                        .then(() =>
                                            console.log("Successful share")
                                        )
                                        .catch((error) =>
                                            console.log("Error sharing:", error)
                                        );
                                }
                            }}
                        >
                            Share
                        </button>
                    </div>
                </div>
            ) : (
                ""
            )}
        </div>
    );
}

export const PostcardSkeleton = () => {
    return (
        <div className="break-inside-avoid-column flex flex-col gap-4  rounded-xl animate-pulse">
            <div className="rounded-xl h-48 bg-slate-100"></div>

            <div className="flex items-center justify-between">
                <div className="w-1/3 h-6 bg-slate-100 rounded-full"></div>
                <div className="flex gap-1 items-center text-slate-600 uppercase ml-auto text-xs">
                    <div className="w-4 h-4 bg-slate-100 rounded-full"></div>
                    <div className="w-16 h-4 bg-slate-100 rounded-full"></div>
                </div>
            </div>

            <div className="hover:underline">
                <h3 className="font-semibold w-3/4 h-6 bg-slate-100 rounded-full"></h3>
            </div>

            <div className="h-20 bg-slate-100 rounded-md"></div>

            <div className="flex gap-1 items-center justify-center">
                <div className="w-1/3 h-8 bg-slate-100 rounded-full"></div>
                <div className="w-1/3 h-8 bg-slate-100 rounded-full"></div>
                <div className="w-1/3 h-8 bg-slate-100 rounded-full"></div>
            </div>
        </div>
    );
};
