import { Link } from "@inertiajs/react";
import React, { useEffect, useRef, useState } from "react";
import ApplicationLogo from "@/Components/ApplicationLogo";
import Modal from "@/Components/Modal";
import axios from "axios";
import TextInput from "@/Components/TextInput";
import Dropdown from "@/Components/Dropdown";

export default function Layout({ user, children, className, header }) {
    const [showMenu, setShowMenu] = useState(false);
    const [showModal, setShowModal] = useState(false);
    const [loading, setLoading] = useState(false);
    const [posts, setPosts] = useState([]);
    const [notificationCount, setNotificationsCount] = useState([0]);
    const searchInput = useRef(null);
    const navlinks = [
        {
            path: "/",
            label: "All posts",
            route: "home",
        },
        // {
        //     path: "/projects",
        //     label: "Porjects",
        //     route: "projects",
        // },
        {
            path: "/about",
            label: "About",
            route: "about",
        },
    ];
    function search(key) {
        if (!key.length) {
            return setPosts([]);
        }
        setLoading(true);
        axios
            .post(route("search"), { key: key })
            .then((res) => {
                const data = res.data.data;
                setPosts(data);
            })
            .catch((error) => console.error(error.response.data.message))
            .finally(() => setLoading(false));
    }

    const debounce = (func, delay) => {
        let timer;
        return function (...args) {
            clearTimeout(timer);
            timer = setTimeout(() => func.apply(this, args), delay);
        };
    };

    const handleSearchChange = (e) => {
        const searchTerm = e.target.value;
        debounceSearch(searchTerm);
    };

    const debounceSearch = debounce(search, 500);

    const closeModalOnEsc = (event) => {
        if (event.keyCode === 27) {
            setShowModal((pre) => !pre);
        }
    };

    useEffect(() => {
        document.addEventListener("keydown", closeModalOnEsc, false);
        if (user) {
            axios
                .post("/api/unread-notifications-count")
                .then((res) => setNotificationsCount(res.data));
        }
    }, []);

    return (
        <main>
            <Modal
                show={showModal}
                onClose={() => setShowModal(false)}
                className="!bg-transparent"
            >
                <div className="py-5">
                    <div className="flex flex-col gap-4 bg-white transition-all ease-in-out duration-300 dark:bg-gray-800 p-3 rounded-xl ">
                        <button
                            type="button"
                            className="flex gap-2 border rounded p-2 ml-auto"
                            onClick={() => setShowModal(false)}
                        >
                            Esc
                            <svg
                                xmlns="http://www.w3.org/2000/svg"
                                fill="none"
                                viewBox="0 0 24 24"
                                strokeWidth={1.5}
                                stroke="currentColor"
                                className="w-6 h-6"
                            >
                                <path
                                    strokeLinecap="round"
                                    strokeLinejoin="round"
                                    d="M6 18L18 6M6 6l12 12"
                                />
                            </svg>
                        </button>
                        <TextInput
                            type="text"
                            className="w-full rounded-md  text-xl "
                            placeholder="Search posts "
                            onChange={handleSearchChange}
                            ref={searchInput}
                        />
                        <div className="mt-5 h-[60vh] flex flex-col gap-4 overflow-y-scroll">
                            {loading ? (
                                [...Array(5)].map((_, index) => (
                                    <div
                                        key={index}
                                        className="block text-xl  text-blue-500 p-3 bg-slate-50 rounded-md"
                                    />
                                ))
                            ) : posts.length ? (
                                <div className="overflow-y-auto max-h-[30vh]">
                                    {posts.map((post) => (
                                        <Link
                                            key={post.id}
                                            href={"/posts/" + post.slug}
                                            className="block text-xl  text-blue-500 p-3 hover:bg-slate-50 rounded-md"
                                        >
                                            {post.title}
                                        </Link>
                                    ))}
                                </div>
                            ) : (
                                ""
                            )}
                        </div>
                    </div>
                </div>
            </Modal>
            <header className="py-5 px-2 sticky top-0 left-0 right-0 bg-white dark:bg-gray-800 z-50 shadow-sm">
                <nav className="flex gap-2 items-center max-w-5xl mx-auto ">
                    <button
                        type="button"
                        onClick={() => setShowMenu((pre) => !pre)}
                        tabIndex="-1"
                        className="lg:hidden navbutton"
                    >
                        {showMenu ? (
                            <svg
                                xmlns="http://www.w3.org/2000/svg"
                                fill="none"
                                viewBox="0 0 24 24"
                                strokeWidth={1.5}
                                stroke="currentColor"
                                className="w-4 h-4"
                            >
                                <path
                                    strokeLinecap="round"
                                    strokeLinejoin="round"
                                    d="M6 18L18 6M6 6l12 12"
                                />
                            </svg>
                        ) : (
                            <svg
                                xmlns="http://www.w3.org/2000/svg"
                                fill="none"
                                viewBox="0 0 24 24"
                                strokeWidth={1.5}
                                stroke="currentColor"
                                className="w-4 h-4"
                            >
                                <path
                                    strokeLinecap="round"
                                    strokeLinejoin="round"
                                    d="M3.75 6.75h16.5M3.75 12h16.5m-16.5 5.25h16.5"
                                />
                            </svg>
                        )}
                    </button>
                    <Link href="/">
                        <div className="w-8 h-8 relative overflow-hidden ">
                            <img
                                src={route("logoUrl")}
                                alt="Hexagon Image"
                                className="w-full h-full object-cover hexagon-mask outline"
                            />
                        </div>
                    </Link>

                    {/* mobile nav */}
                    <div
                        className={
                            " fixed border bg-white  dark:bg-gray-800 p-3 inset-0 transition-all duration-500 ease-in-out max-h-screen overflow-y-auto" +
                            " " +
                            (showMenu ? "top-0" : "-top-[150%]")
                        }
                    >
                        {/* mobile nav */}
                        <div className="flex items-center justify-center  gap-3 flex-col  h-[80%]">
                            {navlinks.map((link, i) => (
                                <Link
                                    href={route(link.route)}
                                    className={
                                        "uplink " +
                                        (route().current(link.route)
                                            ? "font-bold"
                                            : "")
                                    }
                                    key={i}
                                >
                                    {link.label}
                                </Link>
                            ))}
                        </div>
                    </div>

                    {/*desktop nav */}
                    <div className="flex items-center gap-1 ml-auto">
                        <div className=" items-center gap-3  flex">
                            {navlinks.map((link, i) => (
                                <Link
                                    href={route(link.route)}
                                    className={
                                        "uplink hidden lg:block" +
                                        (route().current(link.route)
                                            ? "font-bold"
                                            : "")
                                    }
                                    key={i}
                                >
                                    {link.label}
                                </Link>
                            ))}

                            <a
                                href="/resume.pdf"
                                target="_blank"
                                className="uplink relative"
                            >
                                Resume
                            </a>
                        </div>

                        <button
                            type="button"
                            onClick={() => setShowModal(true)}
                            className="relative navbutton"
                        >
                            <svg
                                xmlns="http://www.w3.org/2000/svg"
                                fill="none"
                                viewBox="0 0 24 24"
                                strokeWidth={1.5}
                                stroke="currentColor"
                                className="w-4 h-4"
                            >
                                <path
                                    strokeLinecap="round"
                                    strokeLinejoin="round"
                                    d="M21 21l-5.197-5.197m0 0A7.5 7.5 0 105.196 5.196a7.5 7.5 0 0010.607 10.607z"
                                />
                            </svg>
                        </button>

                        {user ? (
                            <>
                                <Link
                                    href="/notifications"
                                    className="relative navbutton"
                                >
                                    <svg
                                        xmlns="http://www.w3.org/2000/svg"
                                        fill="none"
                                        viewBox="0 0 24 24"
                                        strokeWidth={1.5}
                                        stroke="currentColor"
                                        className="w-4 h-4"
                                    >
                                        <path
                                            strokeLinecap="round"
                                            strokeLinejoin="round"
                                            d="M14.857 17.082a23.848 23.848 0 005.454-1.31A8.967 8.967 0 0118 9.75v-.7V9A6 6 0 006 9v.75a8.967 8.967 0 01-2.312 6.022c1.733.64 3.56 1.085 5.455 1.31m5.714 0a24.255 24.255 0 01-5.714 0m5.714 0a3 3 0 11-5.714 0"
                                        />
                                    </svg>
                                    {notificationCount &&
                                    notificationCount != 0 ? (
                                        <span className="absolute -top-3 -right-1 text-xs border  rounded-full">
                                            {notificationCount}
                                        </span>
                                    ) : (
                                        ""
                                    )}
                                </Link>
                                <div className=" navbutton">
                                    <Dropdown>
                                        <Dropdown.Trigger
                                            className="!w-full !p-0 !text-inherit"
                                            arrow={false}
                                        >
                                            <svg
                                                xmlns="http://www.w3.org/2000/svg"
                                                fill="none"
                                                viewBox="0 0 24 24"
                                                strokeWidth={1.5}
                                                stroke="currentColor"
                                                className="w-4 h-4"
                                            >
                                                <path
                                                    strokeLinecap="round"
                                                    strokeLinejoin="round"
                                                    d="M17.982 18.725A7.488 7.488 0 0012 15.75a7.488 7.488 0 00-5.982 2.975m11.963 0a9 9 0 10-11.963 0m11.963 0A8.966 8.966 0 0112 21a8.966 8.966 0 01-5.982-2.275M15 9.75a3 3 0 11-6 0 3 3 0 016 0z"
                                                />
                                            </svg>
                                        </Dropdown.Trigger>

                                        <Dropdown.Content
                                            width="100px"
                                            align="right"
                                        >
                                            <Dropdown.Link
                                                href={route("profile.edit")}
                                            >
                                                Profile
                                            </Dropdown.Link>
                                            <Dropdown.Link
                                                href={route("logout")}
                                                as="button"
                                            >
                                                Logout
                                            </Dropdown.Link>
                                        </Dropdown.Content>
                                    </Dropdown>
                                </div>
                            </>
                        ) : (
                            <Link
                                href="/login"
                                className="uplink relative bg-slate-100 px-3 py-1 !rounded-xl"
                            >
                                Login
                            </Link>
                        )}
                    </div>
                </nav>
            </header>
            <article
                className={className + " p-5 max-w-5xl mx-auto min-h-[75vh]"}
            >
                {header && typeof header == "string" ? (
                    <h1 className="font-extrabold mt-10">{header}</h1>
                ) : (
                    header
                )}
                {children}
            </article>

            <footer className="rounded-lg mt-5 dark:bg-gray-800">
                <div className="w-full mx-auto max-w-5xl mx-autol p-4 md:flex md:items-center md:justify-between">
                    <span className="text-sm text-gray-500 sm:text-center dark:text-gray-400">
                        © {new Date().getFullYear()}
                        {", "}
                        <a href="/" className="hover:underline capitalize">
                            {window.location.host}
                        </a>
                        . All Rights Reserved.
                    </span>
                    <ul className="flex flex-wrap items-center mt-3 text-sm font-medium text-gray-500 dark:text-gray-400 sm:mt-0">
                        <li>
                            <Link
                                href={route("about")}
                                className="hover:underline me-4 md:me-6"
                            >
                                About
                            </Link>
                        </li>
                        <li>
                            <Link
                                href={route("pp")}
                                className="hover:underline me-4 md:me-6"
                            >
                                Privacy Policy
                            </Link>
                        </li>

                        <li>
                            <a
                                href="mailto:bhowmikj9432@gmail.com"
                                className="hover:underline"
                            >
                                Contact
                            </a>
                        </li>
                    </ul>
                </div>
            </footer>
        </main>
    );
}
