export const getFirstImageFromMarkdown = (markdown) => {
    // Regular expression to match Markdown image syntax
    const imageRegex = /!\[.*?\]\((.*?)\)/;

    // Find the first match in the Markdown content
    const match = markdown.match(imageRegex);

    // If a match is found, extract the image URL
    if (match) {
        const imageUrl = match[1];

        return imageUrl;
    } else {
        return null;
    }
};
export const stripTags = (input) => {
    return input.replace(/<[^>]*>/g, "");
};

export const dateFormat = (d) => {
    const date = new Date(d);
    const currentDate = new Date();
    const options = {
        month: "short",
        day: "numeric",
        year:
            date.getFullYear() === currentDate.getFullYear()
                ? undefined
                : "numeric",
    };

    return new Intl.DateTimeFormat("en-US", options).format(date);
};

export function countNestedReplies(comment) {
    let totalReplies = comment.replies?.length;

    comment.replies.forEach((reply) => {
        totalReplies += countNestedReplies(reply); // Recursively count nested replies
    });

    return totalReplies;
}

export function calculateReadingTime(text) {
    // Average reading speed in words per minute
    const wordsPerMinute = 200;

    // Calculate the number of words in the text
    const wordCount = text.split(/\s+/).length;

    // Calculate the reading time in minutes
    const readingTime = Math.ceil(wordCount / wordsPerMinute);

    return readingTime;
}

export function countComments(comments) {
    let totalCount = comments.length;

    // Loop through each comment
    comments.forEach((comment) => {
        // Check if the comment has replies
        if (comment.replies && comment.replies.length > 0) {
            // Recursively count replies and add to totalCount
            totalCount += countComments(comment.replies);
        }
    });

    return totalCount;
}

export function setCookie(cname, cvalue, exdays) {
    const d = new Date();
    d.setTime(d.getTime() + exdays * 24 * 60 * 60 * 1000);
    let expires = "expires=" + d.toUTCString();
    document.cookie = cname + "=" + cvalue + ";" + expires + ";path=/";
}
export function getCookie(cname) {
    let name = cname + "=";
    let decodedCookie = decodeURIComponent(document.cookie);
    let ca = decodedCookie.split(";");
    for (let i = 0; i < ca.length; i++) {
        let c = ca[i];
        while (c.charAt(0) == " ") {
            c = c.substring(1);
        }
        if (c.indexOf(name) == 0) {
            return c.substring(name.length, c.length);
        }
    }
    return "";
}

export function isImageFile(inputString) {
    const imageExtensions = /\.(jpeg|jpg|gif|bmp|png)$/i; // Regular expression for common image file extensions

    return imageExtensions.test(inputString);
}
export function addCodeTagFeature(el) {
    //copy code
    const copyButtonLabel = `
<svg height='24' viewBox='0 0 24 24' width='24' xmlns='http://www.w3.org/2000/svg'>
<path d='M7 4V2h10v2h3.007c.548 0 .993.445.993.993v16.014a.994.994 0 0 1-.993.993H3.993A.994.994 0 0 1 3 21.007V4.993C3 4.445 3.445 4 3.993 4H7zm0 2H5v14h14V6h-2v2H7V6zm2-2v2h6V4H9z' fill='currentColor'></path>
</svg>`;

    // use a class selector if available
    let blocks = document.querySelectorAll(el + " pre");

    blocks.forEach((block) => {
        // only add button if browser supports Clipboard API

        if (navigator.clipboard) {
            let button = document.createElement("span");
            button.innerHTML = copyButtonLabel;
            button.classList.add("copy-btn");

            button.addEventListener("click", async () => {
                await copyCode(block, button);
            });

            if (block.querySelector("code")) {
                const codeTag = block.querySelector('code[class*="language-"]');
                let topbar = document.createElement("div");
                topbar.classList.add("tools");
                if (codeTag != undefined) {
                    var arr = codeTag.className.split(" ");
                    var language = arr
                        .filter((e) => e !== "hljs")[0]
                        .split("-")
                        .filter((e) => e !== "language")[0];
                    switch (language) {
                        case "html":
                            language = "HTML";
                            break;
                        case "css":
                            language = "CSS";
                            break;
                        case "javascript":
                            language = "JS";
                            break;
                        case "php":
                            language = "PHP";
                            break;
                        case "python":
                            language = "Python";
                            break;
                        case "ruby":
                            language = "Ruby";
                            break;
                    }
                    const langFlag = document.createElement("span");
                    langFlag.classList.add("langFlag");
                    langFlag.innerText = language;
                    if (language != "undefined") {
                        topbar.appendChild(langFlag);
                        topbar.appendChild(button);
                        block.appendChild(topbar);
                    }
                }
            }
        }
    });
}
async function copyCode(block, button) {
    let code = block.querySelector("code");
    let text = code.innerText;
    await navigator.clipboard.writeText(text);
    button.innerHTML = `
<svg height='24' viewBox='0 0 24 24' width='24' xmlns='http://www.w3.org/2000/svg'>
    <path d='M10 15.172l9.192-9.193 1.415 1.414L10 18l-6.364-6.364 1.414-1.414z' fill='currentColor'></path>
</svg>`;
    setTimeout(() => {
        button.innerHTML = copyButtonLabel;
    }, 2000);
}
