import React, { useState } from "react";
import AuthenticatedLayout from "@/Layouts/AuthenticatedLayout";
import { Datatable, defaultSort } from "joydeep-react-datatable";
import Spinner from "@/Components/Spinner";
import { Link } from "@inertiajs/react";
import axios from "axios";
import Section from "@/Components/Section";

const columns = () => [
    {
        key: "title",
        label: "Title",
        sortable: true,
    },
    {
        key: "description",
        label: "Description",
        value: (row) => {
            if (!row.description) return;
            let str = row.description;
            let maxLength = 50;
            if (str.length <= maxLength) {
                return str; // No need to truncate, the string is already short enough
            } else {
                return str.slice(0, maxLength) + "..."; // Truncate and append "..."
            }
        },
    },
    {
        key: "link",
        label: "Link",
        sortable: true,
        value: (row) => <a href={row.link}>link</a>,
    },
    {
        key: "updated_at",
        label: "Updated at",
        sortable: true,
    },
    {
        key: "...",
        value: (row) => (
            <Link href={"/admin/projects/edit/" + row.id}>
                <svg
                    xmlns="http://www.w3.org/2000/svg"
                    fill="none"
                    viewBox="0 0 24 24"
                    strokeWidth={1.5}
                    stroke="currentColor"
                    className="w-4 h-4"
                >
                    <path
                        strokeLinecap="round"
                        strokeLinejoin="round"
                        d="M16.862 4.487l1.687-1.688a1.875 1.875 0 112.652 2.652L10.582 16.07a4.5 4.5 0 01-1.897 1.13L6 18l.8-2.685a4.5 4.5 0 011.13-1.897l8.932-8.931zm0 0L19.5 7.125M18 14v4.75A2.25 2.25 0 0115.75 21H5.25A2.25 2.25 0 013 18.75V8.25A2.25 2.25 0 015.25 6H10"
                    />
                </svg>
            </Link>
        ),
    },
];

export default function projects({ auth }) {
    const [json, setJson] = useState([]);
    const [data, setData] = useState(json);
    const [loading, setLoading] = useState(false);

    function sort(key, direction) {
        setData(defaultSort({ data, key: key, direction: direction }));
    }
    function getApiParams(data) {
        setLoading(true);
        axios
            .post("/api/projects", data)
            .then((res) => {
                const data = res.data.data;
                console.log(res.data.data.length);
                setJson(data); // Update the json state
                setData(data); // Update the data state
            })
            .catch((error) => console.error(error))
            .finally(() => {
                setLoading(false);
            });
    }

    return (
        <AuthenticatedLayout user={auth.user} header="projects">
            <Section>
                <Datatable
                    columns={columns()}
                    data={data}
                    sort={sort}
                    getApiParams={getApiParams}
                    loading={loading}
                    loader={<Spinner />}
                    pagination={true}
                />
            </Section>
        </AuthenticatedLayout>
    );
}
