import Vr from "@/Components/Vr";
import { useEffect, useState } from "react";
import AuthenticatedLayout from "@/Layouts/AuthenticatedLayout";
import InputError from "@/Components/InputError";
import InputLabel from "@/Components/InputLabel";
import TextInput from "@/Components/TextInput";
import PrimaryButton from "@/Components/PrimaryButton";
import SecondaryButton from "@/Components/SecondaryButton";
import { useForm } from "react-hook-form";
import { router } from "@inertiajs/react";
import Modal from "@/Components/Modal";
import DangerButton from "@/Components/DangerButton";
import "@mdxeditor/editor/style.css";
// importing the editor and the plugin from their full paths

import {
    MDXEditor,
    headingsPlugin,
    listsPlugin,
    quotePlugin,
    thematicBreakPlugin,
    markdownShortcutPlugin,
    toolbarPlugin,
    UndoRedo,
    BoldItalicUnderlineToggles,
    linkPlugin,
    linkDialogPlugin,
    BlockTypeSelect,
    CodeToggle,
    CreateLink,
    InsertTable,
    InsertCodeBlock,
    InsertImage,
    imagePlugin,
    tablePlugin,
    ConditionalContents,
    ChangeCodeMirrorLanguage,
    ShowSandpackInfo,
    codeMirrorPlugin,
    codeBlockPlugin,
    sandpackPlugin,
    diffSourcePlugin,
    DiffSourceToggleWrapper,
    ListsToggle,
} from "@mdxeditor/editor";
import Section from "@/Components/Section";

const defaultSnippetContent = `
export default function App() {
  return (
    <div className="App">
      <h1>Hello CodeSandbox</h1>
      <h2>Start editing to see some magic happen!</h2>
    </div>
  );
}
`.trim();
const simpleSandpackConfig = {
    defaultPreset: "react",
    presets: [
        {
            label: "React",
            name: "react",
            meta: "live react",
            sandpackTemplate: "react",
            sandpackTheme: "dark",
            snippetFileName: "/App.js",
            snippetLanguage: "jsx",
            initialSnippetContent: defaultSnippetContent,
        },
    ],
};

export default function SavePost({ auth, post, topics }) {
    const {
        register,
        handleSubmit,
        formState: { errors },
        setError,
        setValue,
    } = useForm();
    const [processing, setProcessing] = useState(false);
    const [showmodal, setShowmodal] = useState(false);
    const [coverImage, setCoverImage] = useState("");

    const setContent = (data) => {
        setValue("content", data);
    };

    const closeModal = () => {
        setShowmodal(false);
    };

    useEffect(() => {
        if (post) {
            setContent(post.content);
            if (post.cover_image) {
                setCoverImage("/storage/cover/" + post.cover_image);
            }
        }
    }, []);

    return (
        <>
            <AuthenticatedLayout
                user={auth.user}
                header={(post ? "Update" : "Create") + " Post"}
            >
                <form
                    action=""
                    onSubmit={handleSubmit((data) => {
                        const newData = {
                            ...data,
                            post_id: post ? post.id : null,
                            cover_image: data.cover_image
                                ? data.cover_image[0]
                                : null,
                        };
                        router.post(route("admin.posts.save"), newData, {
                            headers: {
                                "Content-Type": "multipart/form-data",
                            },
                            onStart: (visit) => {
                                setProcessing(true);
                            },
                            onFinish: (visit) => {
                                setProcessing(false);
                            },
                            onSuccess: (page) => {},
                            onError: (errors) => {
                                console.log(errors);
                                for (let i in errors) {
                                    setError(i, { message: errors[i] });
                                }
                            },
                        });
                    })}
                    className="flex flex-col gap-5"
                >
                    <div className="ml-auto flex gap-2">
                        {post && (
                            <>
                                <Modal show={showmodal} onClose={closeModal}>
                                    <form className="p-6 w-full">
                                        <h2 className="text-lg font-medium text-gray-900 dark:text-gray-100">
                                            Are you sure ?
                                        </h2>
                                        <div className="mt-6 flex justify-end">
                                            <SecondaryButton
                                                onClick={closeModal}
                                            >
                                                Cancel
                                            </SecondaryButton>

                                            <DangerButton
                                                className="ml-3"
                                                onClick={() => {
                                                    router.post(
                                                        route(
                                                            "admin.posts.delete"
                                                        ),
                                                        { post_id: post.id },
                                                        {
                                                            onStart: (
                                                                visit
                                                            ) => {
                                                                setProcessing(
                                                                    true
                                                                );
                                                            },
                                                            onFinish: (
                                                                visit
                                                            ) => {
                                                                setProcessing(
                                                                    false
                                                                );
                                                            },
                                                            onSuccess: (
                                                                page
                                                            ) => {
                                                                console.log(
                                                                    page
                                                                );
                                                            },
                                                            onError: (
                                                                errors
                                                            ) => {
                                                                console.error(
                                                                    errors
                                                                );
                                                            },
                                                        }
                                                    );
                                                }}
                                                disabled={processing}
                                            >
                                                Delete
                                            </DangerButton>
                                        </div>
                                    </form>
                                </Modal>
                                <SecondaryButton
                                    type="button"
                                    onClick={() => setShowmodal(true)}
                                    disabled={processing}
                                >
                                    Delete
                                </SecondaryButton>
                            </>
                        )}
                        <PrimaryButton disabled={processing}>
                            Save
                        </PrimaryButton>
                    </div>
                    <div className="flex flex-col md:grid grid-cols-[70%_30%] gap-5 ">
                        <Section className="flex flex-col gap-5">
                            <div>
                                {coverImage ? (
                                    <div className="grid grid-cols-2 gap-5">
                                        <img
                                            src={coverImage}
                                            alt=""
                                            className="max-h-40 rounded"
                                        />
                                        <div className="flex flex-col md:flex-row gap-4 items-center">
                                            <SecondaryButton>
                                                <label htmlFor="cover_image">
                                                    Change
                                                </label>
                                            </SecondaryButton>
                                            <button
                                                type="button"
                                                className="text-red-500"
                                                onClick={() => {
                                                    const fileinput =
                                                        document.getElementById(
                                                            "cover_image"
                                                        );
                                                    if (post) {
                                                        return router.post(
                                                            route(
                                                                "deleteCoverImage"
                                                            ),
                                                            {
                                                                post_id:
                                                                    post.id,
                                                            },
                                                            {
                                                                onSuccess() {
                                                                    fileinput.value =
                                                                        "";
                                                                    setCoverImage(
                                                                        ""
                                                                    );
                                                                },
                                                            }
                                                        );
                                                    }

                                                    fileinput.value = "";
                                                    setCoverImage("");
                                                }}
                                            >
                                                Remove
                                            </button>
                                        </div>
                                    </div>
                                ) : (
                                    <SecondaryButton type="button">
                                        <label htmlFor="cover_image">
                                            Add a cover image
                                        </label>
                                    </SecondaryButton>
                                )}
                                <input
                                    onInput={(e) => {
                                        const file = e.target.files[0];
                                        console.log(file);
                                        const objectUrl =
                                            URL.createObjectURL(file);
                                        console.log(objectUrl, file);
                                        setCoverImage(objectUrl);
                                    }}
                                    type="file"
                                    id="cover_image"
                                    accept="image/*"
                                    className="hidden"
                                    {...register("cover_image")}
                                />
                                <InputError
                                    message={
                                        errors.cover_image
                                            ? errors.cover_image.message
                                            : false
                                    }
                                    className="mt-2"
                                />
                            </div>

                            <div>
                                <InputLabel htmlFor="title" value="Title" />

                                <TextInput
                                    defaultValue={post ? post.title : ""}
                                    id="title"
                                    name="title"
                                    className="mt-1 block w-full"
                                    autoComplete="title"
                                    {...register("title", {
                                        required: "The title field is required",
                                    })}
                                />

                                <InputError
                                    message={
                                        errors.title
                                            ? errors.title.message
                                            : false
                                    }
                                    className="mt-2"
                                />
                            </div>

                            <div>
                                <InputLabel htmlFor="slug" value="Slug" />

                                <TextInput
                                    defaultValue={post ? post.slug : ""}
                                    id="Slug"
                                    name="Slug"
                                    className="mt-1 block w-full"
                                    autoComplete="Slug"
                                    {...register("slug", {
                                        required: "The slug field is required",
                                    })}
                                    onChange={(e) => {
                                        e.target.value = e.target.value
                                            .toLowerCase()
                                            .replace(/ /g, "-")
                                            .replace(/-+/g, "-");
                                    }}
                                />

                                <InputError
                                    message={
                                        errors.slug
                                            ? errors.slug.message
                                            : false
                                    }
                                    className="mt-2"
                                />
                            </div>

                            <div>
                                <InputLabel htmlFor="content" value="Content" />
                                <input
                                    type="hidden"
                                    {...register("content", {
                                        required:
                                            "The content field is required",
                                    })}
                                />
                                <InputError
                                    message={
                                        errors.content
                                            ? errors.content.message
                                            : false
                                    }
                                    className="mt-2"
                                />
                            </div>

                            <div className="h-[80vh] overflow-y-scroll">
                                <MDXEditor
                                    className="mt-1"
                                    key="___editor"
                                    onChange={(data) => {
                                        setContent(data);
                                    }}
                                    markdown={post ? post.content : ""}
                                    plugins={[
                                        toolbarPlugin({
                                            toolbarContents: () => (
                                                <DiffSourceToggleWrapper>
                                                    <ConditionalContents
                                                        options={[
                                                            {
                                                                when: (
                                                                    editor
                                                                ) =>
                                                                    editor?.editorType ===
                                                                    "codeblock",
                                                                contents:
                                                                    () => (
                                                                        <ChangeCodeMirrorLanguage />
                                                                    ),
                                                            },
                                                            {
                                                                when: (
                                                                    editor
                                                                ) =>
                                                                    editor?.editorType ===
                                                                    "sandpack",
                                                                contents:
                                                                    () => (
                                                                        <ShowSandpackInfo />
                                                                    ),
                                                            },
                                                            {
                                                                fallback:
                                                                    () => (
                                                                        <>
                                                                            <div className="flex gap-2 items-center">
                                                                                <UndoRedo />
                                                                                <Vr className="h-4" />
                                                                                <BoldItalicUnderlineToggles />
                                                                                <Vr className="h-4" />
                                                                                <ListsToggle />
                                                                                <Vr className="h-4" />
                                                                                <BlockTypeSelect />
                                                                                <Vr className="h-4" />
                                                                                <InsertTable />
                                                                                <CodeToggle />
                                                                                <InsertCodeBlock />
                                                                                <Vr className="h-4" />
                                                                                <CreateLink />
                                                                                <InsertImage />
                                                                            </div>
                                                                        </>
                                                                    ),
                                                            },
                                                        ]}
                                                    />
                                                </DiffSourceToggleWrapper>
                                            ),
                                        }),
                                        // Example Plugin Usage
                                        headingsPlugin(),
                                        listsPlugin(),
                                        quotePlugin(),
                                        thematicBreakPlugin(),
                                        markdownShortcutPlugin(),
                                        linkPlugin(),
                                        linkDialogPlugin(),
                                        tablePlugin(),
                                        imagePlugin(),
                                        codeBlockPlugin({
                                            defaultCodeBlockLanguage: "js",
                                        }),
                                        sandpackPlugin({
                                            sandpackConfig:
                                                simpleSandpackConfig,
                                        }),
                                        diffSourcePlugin({
                                            diffMarkdown: "An older version",
                                            viewMode: "rich-text",
                                        }),
                                        codeMirrorPlugin({
                                            codeBlockLanguages: {
                                                js: "JavaScript",
                                                css: "CSS",
                                                html: "HTML",
                                                php: "PHP",
                                                python: "Python",
                                                java: "Java",
                                                ruby: "Ruby",
                                                swift: "Swift",
                                                typescript: "TypeScript",
                                                go: "Go",
                                            },
                                        }),
                                    ]}
                                />
                            </div>
                        </Section>
                        <div className="flex-col flex gap-5">
                            <Section title="Topic">
                                <select
                                    {...register("topic")}
                                    defaultValue={post ? post.topic?.id : ""}
                                    className="w-full border-gray-300 dark:border-gray-700 dark:bg-gray-900 dark:text-gray-300 focus:border-indigo-500 dark:focus:border-indigo-600 focus:ring-indigo-500 dark:focus:ring-indigo-600 rounded-md shadow-sm "
                                >
                                    <option value="">Select topic</option>
                                    {topics &&
                                        topics.map((o, i) => (
                                            <option value={o.id} key={o.id}>
                                                {o.name}
                                            </option>
                                        ))}
                                </select>
                            </Section>
                            <Section title="Visibility">
                                <select
                                    {...register("visibility")}
                                    defaultValue={post ? post.visibility : ""}
                                    className="w-full border-gray-300 dark:border-gray-700 dark:bg-gray-900 dark:text-gray-300 focus:border-indigo-500 dark:focus:border-indigo-600 focus:ring-indigo-500 dark:focus:ring-indigo-600 rounded-md shadow-sm "
                                >
                                    <option value="">Select visibility</option>
                                    <option value="private" key="0">
                                        Private
                                    </option>
                                    <option value="public" key="1">
                                        Public
                                    </option>
                                </select>
                            </Section>
                        </div>
                    </div>
                </form>
            </AuthenticatedLayout>
        </>
    );
}
