import { useState } from "react";
import AuthenticatedLayout from "@/Layouts/AuthenticatedLayout";
import InputError from "@/Components/InputError";
import InputLabel from "@/Components/InputLabel";
import TextInput from "@/Components/TextInput";
import Textarea from "@/Components/Textarea";
import PrimaryButton from "@/Components/PrimaryButton";
import SecondaryButton from "@/Components/SecondaryButton";
import { useForm } from "react-hook-form";
import { router } from "@inertiajs/react";
import Modal from "@/Components/Modal";
import DangerButton from "@/Components/DangerButton";
import Section from "@/Components/Section";

export default function SaveTopic({ auth, topic }) {
    const {
        register,
        handleSubmit,
        formState: { errors },
        setError,
    } = useForm();
    const [processing, setProcessing] = useState(false);
    const [showmodal, setShowmodal] = useState(false);

    const closeModal = () => {
        setShowmodal(false);
    };

    return (
        <AuthenticatedLayout
            user={auth.user}
            header={(topic ? "Update" : "Create") + " Topic"}
        >
            <form
                className="flex flex-col gap-5"
                onSubmit={handleSubmit((data) => {
                    const newData = {
                        ...data,
                        topic_id: topic ? topic.id : null,
                    };
                    router.post(route("admin.topics.save"), newData, {
                        onStart: (visit) => {
                            setProcessing(true);
                        },
                        onFinish: (visit) => {
                            setProcessing(false);
                        },
                        onSuccess: (page) => {},
                        onError: (errors) => {
                            console.log(errors);
                            for (let i in errors) {
                                setError(i, { message: errors[i] });
                            }
                        },
                    });
                })}
            >
                <div className="ml-auto flex gap-2">
                    {topic && (
                        <>
                            <Modal show={showmodal} onClose={closeModal}>
                                <form className="p-6 w-full">
                                    <h2 className="text-lg font-medium text-gray-900 dark:text-gray-100">
                                        Are you sure ?
                                    </h2>
                                    <div className="mt-6 flex justify-end">
                                        <SecondaryButton onClick={closeModal}>
                                            Cancel
                                        </SecondaryButton>

                                        <DangerButton
                                            className="ml-3"
                                            onClick={() => {
                                                router.post(
                                                    route(
                                                        "admin.topics.delete"
                                                    ),
                                                    { topic_id: topic.id },
                                                    {
                                                        onStart: (visit) => {
                                                            setProcessing(true);
                                                        },
                                                        onFinish: (visit) => {
                                                            setProcessing(
                                                                false
                                                            );
                                                        },
                                                        onSuccess: (page) => {
                                                            console.log(page);
                                                        },
                                                        onError: (errors) => {
                                                            console.error(
                                                                errors
                                                            );
                                                        },
                                                    }
                                                );
                                            }}
                                            disabled={processing}
                                        >
                                            Delete
                                        </DangerButton>
                                    </div>
                                </form>
                            </Modal>
                            <SecondaryButton
                                type="button"
                                onClick={() => setShowmodal(true)}
                                disabled={processing}
                            >
                                Delete
                            </SecondaryButton>
                        </>
                    )}
                    <PrimaryButton disabled={processing}>Save</PrimaryButton>
                </div>
                <Section className="flex flex-col gap-5">
                    <div className="flex  flex-col  lg:flex-row gap-5">
                        <div className="w-full">
                            <InputLabel htmlFor="name" value="Name" />

                            <TextInput
                                defaultValue={topic ? topic.name : ""}
                                id="name"
                                name="name"
                                className="mt-1 block w-full"
                                autoComplete="name"
                                {...register("name", {
                                    required: "The name field is required",
                                })}
                            />

                            <InputError
                                message={
                                    errors.name ? errors.name.message : false
                                }
                                className="mt-2"
                            />
                        </div>

                        <div className="w-full">
                            <InputLabel htmlFor="color" value="Color" />

                            <TextInput
                                type="color"
                                defaultValue={topic ? topic.color : ""}
                                id="color"
                                name="color"
                                className="mt-1 block w-full h-10"
                                autoComplete="color"
                                {...register("color", {
                                    required: "The color field is required",
                                })}
                            />

                            <InputError
                                message={
                                    errors.name ? errors.name.message : false
                                }
                                className="mt-2"
                            />
                        </div>
                    </div>

                    <div>
                        <InputLabel htmlFor="description" value="Description" />
                        <Textarea
                            defaultValue={topic ? topic.description : ""}
                            id="description"
                            name="description"
                            className="mt-1 block w-full"
                            autoComplete="description"
                            {...register("description")}
                        />

                        <InputError
                            message={
                                errors.description
                                    ? errors.description.message
                                    : false
                            }
                            className="mt-2"
                        />
                    </div>
                </Section>
            </form>
        </AuthenticatedLayout>
    );
}
