import { Alert } from "@/Components/Alert";
import InputError from "@/Components/InputError";
import InputLabel from "@/Components/InputLabel";
import PrimaryButton from "@/Components/PrimaryButton";
import Section from "@/Components/Section";
import TextInput from "@/Components/TextInput";
import Authenticated from "@/Layouts/AuthenticatedLayout";
import { router } from "@inertiajs/react";
import { useForm } from "react-hook-form";

export default function SendNotifications({ auth }) {
    const {
        handleSubmit,
        formState: { errors },
        register,
        setError,
    } = useForm();
    return (
        <Authenticated user={auth.user} header="Notification / send">
            <Section title="Compose Notification">
                <form
                    action=""
                    onSubmit={handleSubmit((data) => {
                        router.post(route("compose"), data, {
                            onSuccess() {
                                Alert({
                                    type: "success",
                                    title: "Notificaion sent",
                                    message: "Notificaion send to All users",
                                });
                            },
                            onError: (errors) => {
                                for (let i in errors) {
                                    setError(i, { message: errors[i] });
                                }
                            },
                        });
                    })}
                >
                    <div className="mt-4">
                        <InputLabel htmlFor="to" value="To" />

                        <TextInput
                            id="to"
                            name="to"
                            className="mt-1 block w-full"
                            {...register("to", {
                                required: "The to field is required",
                            })}
                        />

                        <InputError
                            message={
                                errors.title ? errors.title.message : false
                            }
                            className="mt-2"
                        />
                    </div>

                    <div className="mt-4">
                        <InputLabel htmlFor="title" value="Title" />

                        <TextInput
                            id="title"
                            name="title"
                            className="mt-1 block w-full"
                            {...register("title", {
                                required: "The title field is required",
                            })}
                        />

                        <InputError
                            message={
                                errors.title ? errors.title.message : false
                            }
                            className="mt-2"
                        />
                    </div>

                    <div className="mt-4">
                        <InputLabel htmlFor="imageUrl" value="Image Url" />

                        <TextInput
                            id="imageUrl"
                            name="imageUrl"
                            className="mt-1 block w-full"
                            {...register("imageUrl", {
                                required: "The imageUrl field is required",
                            })}
                        />

                        <InputError
                            message={
                                errors.imageUrl
                                    ? errors.imageUrl.message
                                    : false
                            }
                            className="mt-2"
                        />
                    </div>

                    <div className="mt-4">
                        <InputLabel htmlFor="body" value="Body" />

                        <TextInput
                            id="body"
                            name="body"
                            className="mt-1 block w-full"
                            {...register("body", {
                                required: "The body field is required",
                            })}
                        />

                        <InputError
                            message={errors.body ? errors.body.message : false}
                            className="mt-2"
                        />
                    </div>

                    <div className="mt-4">
                        <InputLabel htmlFor="action" value="Action" />

                        <TextInput
                            id="action"
                            name="action"
                            className="mt-1 block w-full"
                            {...register("action", {
                                required: "The action field is required",
                            })}
                        />

                        <InputError
                            message={
                                errors.action ? errors.action.message : false
                            }
                            className="mt-2"
                        />
                    </div>

                    <PrimaryButton type="submit" className="mt-5">
                        Send
                    </PrimaryButton>
                </form>
            </Section>
        </Authenticated>
    );
}
