import Checkbox from "@/Components/Checkbox";
import { useState } from "react";
import GuestLayout from "@/Layouts/GuestLayout";
import InputError from "@/Components/InputError";
import InputLabel from "@/Components/InputLabel";
import TextInput from "@/Components/TextInput";
import PrimaryButton from "@/Components/PrimaryButton";

import { Link, router } from "@inertiajs/react";
import { useForm } from "react-hook-form";
import AuthWith from "@/Components/AuthWith";
import BackOrHome from "@/Components/BackOrHome";

export default function Login({ status, canResetPassword }) {
    const {
        register,
        handleSubmit,
        formState: { errors },
        setError,
    } = useForm();
    const [processing, setProcessing] = useState(false);
    return (
        <GuestLayout>
            {status && (
                <div className="mb-4 font-medium text-sm text-green-600">
                    {status}
                </div>
            )}
            <BackOrHome />
            <br />
            <form
                onSubmit={handleSubmit((data) => {
                    router.post(route("login"), data, {
                        onStart: (visit) => {
                            setProcessing(true);
                        },
                        onFinish: (visit) => {
                            setProcessing(false);
                        },
                        onSuccess: (page) => {},
                        onError: (errors) => {
                            for (let i in errors) {
                                setError(i, { message: errors[i] });
                            }
                        },
                    });
                })}
            >
                <h1>Sign in</h1>

                <div className="mt-4">
                    <InputLabel htmlFor="email" value="Email" />

                    <TextInput
                        id="email"
                        type="email"
                        name="email"
                        className="mt-1 block w-full"
                        autoComplete="username"
                        {...register("email", {
                            required: "The email field is required",
                        })}
                    />

                    <InputError
                        message={errors.email ? errors.email.message : false}
                        className="mt-2"
                    />
                </div>

                <div className="mt-4">
                    <div className="flex">
                        <InputLabel htmlFor="password" value="Password" />

                        {canResetPassword && (
                            <Link
                                href={route("password.request")}
                                className="ml-auto  text-sm text-gray-600 dark:text-gray-400 hover:text-gray-900 dark:hover:text-gray-100 rounded-md focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 dark:focus:ring-offset-gray-800"
                            >
                                Forgot your password?
                            </Link>
                        )}
                    </div>

                    <TextInput
                        id="password"
                        type="password"
                        name="password"
                        className="mt-1 block w-full"
                        autoComplete="current-password"
                        {...register("password", {
                            required: "The password field is required",
                        })}
                    />

                    <InputError
                        message={
                            errors.password ? errors.password.message : false
                        }
                        className="mt-2"
                    />
                </div>

                <div className="block mt-4">
                    <label className="flex items-center">
                        <Checkbox name="remember" {...register("checked")} />
                        <span className="ml-2 text-sm text-gray-600 dark:text-gray-400">
                            Remember me
                        </span>
                    </label>
                </div>

                <PrimaryButton
                    className="mt-4 w-full items-center"
                    disabled={processing}
                >
                    Login
                </PrimaryButton>

                <AuthWith className="mt-4" />

                <div className="mt-4 text-center">
                    Don't have an account?
                    <Link
                        href={route("register")}
                        className="ml-1   text-gray-600 dark:text-gray-400 hover:text-gray-900 dark:hover:text-gray-100 rounded-md focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 dark:focus:ring-offset-gray-800"
                    >
                        Create
                    </Link>
                </div>
            </form>
        </GuestLayout>
    );
}
