import { useState } from "react";
import GuestLayout from "@/Layouts/GuestLayout";
import InputError from "@/Components/InputError";
import InputLabel from "@/Components/InputLabel";
import PrimaryButton from "@/Components/PrimaryButton";
import TextInput from "@/Components/TextInput";
import { Link, router } from "@inertiajs/react";
import { useForm } from "react-hook-form";
import AuthWith from "@/Components/AuthWith";
import BackOrHome from "@/Components/BackOrHome";

export default function Register() {
    const {
        register,
        handleSubmit,
        formState: { errors },
        setError,
    } = useForm();
    const [processing, setProcessing] = useState(false);

    return (
        <GuestLayout>
            <BackOrHome />
            <br />
            <form
                onSubmit={handleSubmit((data) => {
                    router.post(route("register"), data, {
                        onStart: (visit) => {
                            setProcessing(true);
                        },
                        onFinish: (visit) => {
                            setProcessing(false);
                        },
                        onSuccess: (page) => {},
                        onError: (errors) => {
                            console.log(errors);
                            for (let i in errors) {
                                setError(i, { message: errors[i] });
                            }
                        },
                    });
                })}
            >
                <h1>Creat Your Account</h1>

                <div className="mt-4">
                    <InputLabel htmlFor="name" value="Name" />

                    <TextInput
                        id="name"
                        name="name"
                        className="mt-1 block w-full"
                        autoComplete="name"
                        {...register("name", {
                            required: "The name field is required",
                        })}
                    />

                    <InputError
                        message={errors.name ? errors.name.message : false}
                        className="mt-2"
                    />
                </div>

                <div className="mt-4">
                    <InputLabel htmlFor="email" value="Email" />

                    <TextInput
                        id="email"
                        type="email"
                        name="email"
                        className="mt-1 block w-full"
                        autoComplete="username"
                        {...register("email", {
                            required: "The email field is required",
                        })}
                    />

                    <InputError
                        message={errors.email ? errors.email.message : false}
                        className="mt-2"
                    />
                </div>

                <div className="mt-4">
                    <InputLabel htmlFor="password" value="Password" />
                    <TextInput
                        id="password"
                        type="password"
                        name="password"
                        className="mt-1 block w-full"
                        autoComplete="new-password"
                        {...register("password", {
                            required: "The password field is required",
                            minLength: {
                                value: 8,
                                message:
                                    "The password field must be at least 8 characters.",
                            },
                            validate: (value, formValues) => {
                                if (value != formValues.password_confirmation) {
                                    return "The password field confirmation does not match";
                                }
                            },
                        })}
                    />

                    <InputError
                        message={
                            errors.password ? errors.password.message : false
                        }
                        className="mt-2"
                    />
                </div>

                <div className="mt-4">
                    <InputLabel
                        htmlFor="password_confirmation"
                        value="Confirm Password"
                    />

                    <TextInput
                        id="password_confirmation"
                        type="password"
                        name="password_confirmation"
                        className="mt-1 block w-full"
                        autoComplete="new-password"
                        {...register("password_confirmation", {
                            required:
                                "The password confirmation field is required",
                        })}
                    />

                    <InputError
                        message={
                            errors.password_confirmation
                                ? errors.password_confirmation.message
                                : false
                        }
                        className="mt-2"
                    />
                </div>

                <PrimaryButton
                    className="mt-4 w-full items-center"
                    disabled={processing}
                >
                    Creare account
                </PrimaryButton>

                <AuthWith className="mt-4" />

                <div className="mt-4 text-center">
                    Already have an account?
                    <Link
                        href={route("login")}
                        className="ml-1  text-gray-600 dark:text-gray-400 hover:text-gray-900 dark:hover:text-gray-100 rounded-md focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 dark:focus:ring-offset-gray-800"
                    >
                        Login
                    </Link>
                </div>
            </form>
        </GuestLayout>
    );
}
