import React, { useState, useEffect } from "react";
import Layout from "@/Layouts/Layout";
import { requestPermission } from "@/Notification";
import InfiniteScroll from "react-infinite-scroll-component";
import { Link } from "@inertiajs/react";
import { dateFormat } from "@/Libs/Common";
import { useRemember } from "@inertiajs/react";

import ToggleNotificationPermission from "@/Components/ToggleNotificationPermission";

export default function Notifications({ auth }) {
    const [state, setState] = useRemember({
        data: [],
        page: 1,
        hasMore: true,
    });

    console.log(state);

    // Function to fetch data from the API
    // Function to fetch data from the API
    const fetchData = async () => {
        try {
            const req = await window.axios.post("/api/notifications", {
                page: state.page,
            });

            const newData = req.data.data;

            if (newData.length > 0) {
                setState((prevState) => {
                    // Extract unique IDs from the existing data
                    const existingIds = new Set(
                        prevState.data.map((item) => item.id)
                    );

                    // Filter out duplicates from the fetched data
                    const filteredData = newData.filter(
                        (item) => !existingIds.has(item.id)
                    );

                    return {
                        page: prevState.page + 1,
                        data: [...prevState.data, ...filteredData],
                        hasMore: req.data.next_page_url !== null,
                    };
                });
            } else {
                setState((prevState) => {
                    return {
                        ...prevState,
                        hasMore: req.data.next_page_url !== null,
                    };
                });
            }
        } catch (error) {
            console.error("Error fetching data:", error);
        }
    };

    useEffect(() => {
        fetchData();
        requestPermission({ device_token: auth.user.device_token });
    }, []);

    return (
        <Layout
            user={auth.user}
            className="space-y-10"
            header={
                <div className="flex mt-10  items-center">
                    <h1 className=" font-extrabold">Notifications</h1>
                    <ToggleNotificationPermission
                        className="ml-auto"
                        auth={auth}
                    />
                </div>
            }
        >
            {/* Infinite scroll */}

            <InfiniteScroll
                dataLength={state.data.length}
                next={fetchData}
                hasMore={state.hasMore}
                loader={
                    <div className="py-2 divide-y">
                        <div className="animate-pulse space-y-3">
                            {[...Array(5)].map((_, index) => (
                                <div
                                    className="block py-3 space-y-2"
                                    key={index}
                                >
                                    <div className="mx-2 bg-slate-100 h-4 "></div>
                                    <div className="text-gray-600 mx-2 bg-slate-100 h-10 "></div>
                                    {index == 1 ? (
                                        <div className="w-full max-w-xs mx-2 bg-slate-100 h-40 "></div>
                                    ) : (
                                        ""
                                    )}
                                </div>
                            ))}
                        </div>
                    </div>
                }
                endMessage={
                    <p style={{ textAlign: "center" }}>
                        {state.data.length
                            ? "Yay! You have seen it all"
                            : "No notifications"}
                    </p>
                }
            >
                {/* Your notification list */}
                <div className="py-2 divide-y">
                    {state.data.map((item, index) => (
                        <Link
                            href="/"
                            key={index}
                            className="block py-3  hover:bg-gray-100 space-y-3 text-sm"
                        >
                            <div className="mx-2 uplink px-0">
                                {dateFormat(item.created_at)}
                            </div>
                            <div className="text-gray-600  mx-2">
                                {item.data.title}
                            </div>
                            {item.data.image && (
                                <img
                                    src={item.data.image}
                                    className="w-full max-w-xs rounded-md mx-2"
                                />
                            )}
                        </Link>
                    ))}
                </div>
            </InfiniteScroll>
        </Layout>
    );
}
